==> igniteui-react-16.16.2.tgz: package/esm5/lib/Toast.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var Toast = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Toast, _super);
    function Toast() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(Toast.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toast.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.a.d = this.f;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toast.prototype, "d", {
        get: function () {
            var ret_ = this.b.c("open");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("open", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toast.prototype, "e", {
        get: function () {
            var ret_ = this.b.c("displayTime");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("displayTime", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toast.prototype, "c", {
        get: function () {
            var ret_ = this.b.c("keepOpen");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.i("keepOpen", value_);
        },
        enumerable: false,
        configurable: true
    });
    Toast.prototype.h = function () {
        this.nativeElement.hide();
    };
    Toast.prototype.i = function () {
        this.nativeElement.show();
    };
    Toast.prototype.j = function () {
        this.nativeElement.toggle();
    };
    Toast.$t = markType(Toast, 'Toast', BaseElement.$);
    return Toast;
}(BaseElement));
export { Toast };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/Toast.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var Toast = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Toast, _super);
    function Toast() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(Toast.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toast.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.a.o = this.f;
        },
        enumerable: false,
        configurable: true
    });
    Toast.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Toast.prototype, "d", {
        get: function () {
            var ret_ = this.b.n("open");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("open", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toast.prototype, "e", {
        get: function () {
            var ret_ = this.b.n("displayTime");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("displayTime", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Toast.prototype, "c", {
        get: function () {
            var ret_ = this.b.n("keepOpen");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.b.v("keepOpen", value_);
        },
        enumerable: false,
        configurable: true
    });
    Toast.prototype.i = function () {
        this.nativeElement.hide();
    };
    Toast.prototype.k = function () {
        this.nativeElement.show();
    };
    Toast.prototype.l = function () {
        this.nativeElement.toggle();
    };
    Toast.prototype.h = function () {
        this.nativeElement.connectedCallback();
    };
    Toast.$t = markType(Toast, 'Toast', BaseElement.$);
    return Toast;
}(BaseElement));
export { Toast };
